########################################################
## no customization should be needed in this Makefile ##
########################################################

## compiler flags
ALLLIBS := $(LIBAL4) $(LIBAL5)
CXXFLAGS := $(OPTS) $(LIBSW)
DEBUGOPTS := -g -Wall -DDEBUG

## standard make targets
all : bin/hexwars
install :
	install -d $(BINDIR)
	install bin/hexwars $(BINDIR)
	install -d $(CNTDIR)/maps/
	install -m a+r maps/* $(CNTDIR)/maps/
	install -d $(CNTDIR)/graphics/bitmap/128x64/modernart/
	install -m a+r graphics/bitmap/128x64/modernart/* \
		$(CNTDIR)/graphics/bitmap/128x64/modernart/
	install -d $(DESTDIR)/usr/share/applications/
	install misc/hexwars.desktop $(DESTDIR)/usr/share/applications/
	install -d $(DESTDIR)/usr/share/pixmaps/
	install -m a+r misc/hexwars.xpm $(DESTDIR)/usr/share/pixmaps/
uninstall :
	rm $(BINDIR)/hexwars
	rm -rf $(CNTDIR)
	rm $(DESTDIR)/usr/share/applications/hexwars.desktop
	rm $(DESTDIR)/usr/share/pixmaps/hexwars.xpm
clean :
	@echo "Removing binary (*.o, bin/*, test/*) and"\
	      "dependency information (*.dep) files.";\
	rm -f $(subst .cpp,.dep,$(SRC));\
	rm -f $(subst .cpp,.o,$(SRC));\
	rm -f hexwars bin/* test/*;\

.PHONY : clean install uninstall dep

## other make targets
cleanDebug :
	make clean && make Debug
Debug :
	make OPTS="$(DEBUGOPTS)" bin/hexwars
cleanRelease :
	make clean && make Release
Release :
	make bin/hexwars
Test :
	make OPTS="$(DEBUGOPTS)" test/Unit-Fighting
	make OPTS="$(DEBUGOPTS)" test/Coordinates
	make OPTS="$(DEBUGOPTS)" test/MenuItem
	make OPTS="$(DEBUGOPTS)" test/PathName
	make OPTS="$(DEBUGOPTS)" test/FSHandler
	make OPTS="$(DEBUGOPTS)" test/MapLoader
	make OPTS="$(DEBUGOPTS)" test/UIEngine
tidy :
	@echo "Removing binary files (.o, bin/*, test/*).";\
	rm -f $(subst .cpp,.o,$(SRC));\
	rm -f hexwars bin/* test/*;\

## resolve dependencies
-include $(subst .cpp,.dep,$(SRC))

## real  make targets
bin/hexwars : $(SRC_HEXWARS_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)
test/Unit-Fighting : $(SRC_SHARED_UNITS_UNIT_FIGHTING_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^
test/Coordinates : $(SRC_SHARED_DEFINITIONS_COORDINATES_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^
test/MenuItem : $(SRC_SHARED_GUI_MENUITEM_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)
test/UIEngine : $(SRC_SHARED_GUI_UIENGINE_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)
test/PathName : $(SRC_SHARED_FILESYSTEM_PATHNAME_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)
test/FSHandler : $(SRC_SHARED_FILESYSTEM_FSHANDLER_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)
test/MapLoader : $(SRC_SHARED_FILESYSTEM_MAPLOADER_TEST_O)
	$(CXX) $(CXXFLAGS) -o $@ $^ $(ALLLIBS)

%.dep: %.cpp
	@echo "Creating $@";\
	$(CXX) -MM $(CXXFLAGS) $< > $@.tmp;\
	sed -i 's!$*\.hpp!!' $@.tmp;\
	sed -i 's![^ ]*\.o!$*\.o!' $@.tmp;\
	sed -i '/\/\.\.\/[^ ]\+\/\.\.\//d' $@.tmp;\
	sed -i 's!/[^/]\+/\.\./!/!g' $@.tmp;\
# HACK: collapse some more ../\
	sed -i 's!/[^/]\+/\.\./!/!g' $@.tmp;\
	sed -i 's!/[^/]\+/\.\./!/!g' $@.tmp;\
	sed -i 's!/[^/]\+/\.\./!/!g' $@.tmp;\
# /HACK\
	sed -i 's!p s!p $$(s!g' $@.tmp;\
	sed -i 's! src/! $$(src/!g' $@.tmp;\
	sed -i 's!\.hpp!_O)!g' $@.tmp;\
	sed -i 's!\.o!_O!g' $@.tmp;\
	sed -i 'y!/-!__!' $@.tmp;\
	sed -i 's!\:! \:=!g' $@.tmp;\
	tr '[:lower:]' '[:upper:]' < $@.tmp >> $@;\
	sed -i 's![^ ]*CPP!$*\.o!g' $@;\
	echo "" >> $@;\
	$(CXX) -MM $(CXXFLAGS) $< > $@.tmp;\
	sed -i 's![^ ]*\.o!$*\.o!' $@.tmp;\
	cat $@.tmp >> $@;\
	rm $@.tmp;\
	echo "" >> $@

