/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "EditorMainMenu.hpp"

EditorMainMenu::EditorMainMenu(UIMenu* uim){
    myui = uim;
    display = uim;
    plyr = PLAYER1;
    unit = NOUNIT;
    item.push_back(new MenuItem("Menu", HEADLINE));
    item.push_back(new MenuItem("Player 1", SELECTED));
    item.push_back(new MenuItem("Land/Water", ENABLED));
    item.push_back(new MenuItem("Save map", ENABLED));
    item.push_back(new MenuItem("Quit", ENABLED));
    selectItem(1);
}

EditorMainMenu::~EditorMainMenu(){
    clear();
}

PLAYER EditorMainMenu::getPlayerNumber() {
    return plyr;
}

UNITTYPE EditorMainMenu::getUnittype() {
    return unit;
}

void EditorMainMenu::runItem(unsigned int itemno, int mod){
    switch (itemno){
    case 1:
        if (plyr == PLAYER1) {
            plyr = PLAYER2;
            currinput = SWITCH2P2;
        } else {
            plyr = PLAYER1;
            currinput = SWITCH2P1;
        }
        delete item[1];
        item[1] = new MenuItem("Player "+convertInt(plyr), SELECTED);
        refresh();
        break;
    case 2:
        switch (mod) {
        case -1:
            unit--;
            break;
        default:
            if (unit < SPIRIT) {
                unit++;
            } else {
                unit = NOUNIT;
            }
            break;
        }
        refreshUnitButton();
        currinput = SELECTUNIT;
        break;
    case 3:
        currinput = SAVE;
        break;
    case 4:
        currinput = QUIT;
        break;
    default:
        break;
    }
}

void EditorMainMenu::refreshUnitButton() {
    if (unit > SPIRIT) {
        unit = SPIRIT;
    }
    delete item[2];
    std::string unitname;
    switch (unit) {
    case NOUNIT:
        unitname = "Land/Water";
        break;
    case MAGICIAN:
        unitname = "Magician";
        break;
    case WARRIOR:
        unitname = "Warrior";
        break;
    case SCOUT:
        unitname = "Scout";
        break;
    case TERRAFORMER:
        unitname = "Terraformer";
        break;
    case SPIRIT:
        unitname = "Spirit";
        break;
    default:
        break;
    }
    item[2] = new MenuItem(unitname, SELECTED);
    refresh();
}

