/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "HotSeat.hpp"

HotSeat::HotSeat(GraphicSet* gs, BasicUserInterface* bui, FSHandler* fsh){
    init(gs, bui, fsh);

    psm = NULL;
    server = NULL;
}

HotSeat::~HotSeat(){
    for (unsigned int i=0; i<map.size(); i++) {
        delete map[i];
        map[i] = NULL;
    }

    for (unsigned int i=0; i<units.size(); i++) {
        delete units[i];
        units[i] = NULL;
    }


    for (unsigned int i=0; i<client.size(); i++) {
        delete client[i];
        client[i] = NULL;
    }
    delete uim;
    delete psm;
    delete server;
}

void HotSeat::startGame(std::string level){
    // init logical elements
    server = new Server(level, fshandler);

    map.push_back(new Map(*(server->getMap(PLAYER1))));
    map.push_back(new Map(*(server->getMap(PLAYER2))));
    units.push_back(new UnitContainer(*(server->getUnits(PLAYER1))));
    units.push_back(new UnitContainer(*(server->getUnits(PLAYER2))));
    client.push_back(new Client( graphicset, basicuserinterface,
                                 map[0], units[0], PLAYER1));
    client.push_back(new Client( graphicset, basicuserinterface,
                                 map[1], units[1], PLAYER2));
}

RUNMODE HotSeat::run(){

    switch ( startGameMenu() ) {
    case QUIT:
        return LOBBY;
        break;
    default:
        startGame(levelname);
        break;
    }

    psm = new PlayerSwitchMenu(uim);
    psm->refresh();

    bool loop = true;
    // loop of hotseat game
    while (loop) {
        currinput = basicuserinterface->getInput(NOINPUT);
        switch(currinput){
        case NOINPUT:
            psm->print();
            break;
        case QUIT:
            return LOBBY;
        case TIME:
            break;
        default:
            switch(psm->getInput(currinput)){
            case P0AICMD:
                units[0]->giveRandomOrders(PLAYER1);
                units[1]->giveRandomOrders(PLAYER2);
                endRound();
                break;
            case P1AICMD:
                units[0]->giveRandomOrders(PLAYER1);
                endRound();
                break;
            case P2AICMD:
                units[1]->giveRandomOrders(PLAYER2);
                endRound();
                break;
            case ENDROUND:
                endRound();
                break;
            case QUIT:
                return LOBBY;
            case SELECT:
                psm->refresh();
                break;
            case SWITCH2P1:
                client[0]->clientLoop();
                psm->refresh();
                break;
            case SWITCH2P2:
                client[1]->clientLoop();
                psm->refresh();
                break;
            case SAVEGAME:
                server->saveGame();
                break;
            default:
                break;
            }
        }
    // end of loop of hotseat game
    }
    return LOBBY;
}

void HotSeat::endRound() {
    server->updateUnits(units[0], PLAYER1);
    server->updateUnits(units[1], PLAYER2);
    server->endRound();
    server->doMovement();
    units[0]->sync(server->getUnits(PLAYER1));
    units[1]->sync(server->getUnits(PLAYER2));
    map[0]->sync(server->getMap(PLAYER1));
    map[1]->sync(server->getMap(PLAYER2));
    //HACK: server ought to have a nice tidy method
    server->getUnits(PLAYER2)->tidy();


    if (!server->getUnits(PLAYER2)->checkForUnit(MAGICIAN, PLAYER2)){
        psm->setWinner(1);
    } else if (!server->getUnits(PLAYER1)->checkForUnit(MAGICIAN, PLAYER1)){
        psm->setWinner(2);
    }
    psm->refresh();
}
