/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Lobby.hpp"

Lobby::Lobby(GraphicSet* ogs, BasicUserInterface* obui){
    bui = obui;
    gs = ogs;
    ui_menu = new UIMenu(bui->getSize(),Coordinates(0,0),ogs,obui);
    oldmenu = NULL;
    menu = new MainMenu(ui_menu, this);
}

Lobby::~Lobby(){
    delete menu;
    delete oldmenu;
    delete ui_menu;
}

RUNMODE Lobby::run(){
    nextrunmode = LOBBY;
    menu->refresh();
    while (nextrunmode == LOBBY){
        currinput = bui->getInput(NOINPUT);
        switch(currinput){
        case NOINPUT:
            menu->print();
            break;
        case TIME:
            break;
        default:
            switch(menu->getInput(currinput)){
            case SCROLL:
                break;
            case SELECT:
                menu->refresh();
                break;
            case QUIT:
                menu = new QuitMenu(ui_menu, this);
                menu->refresh();
                break;
            default:
                break;
            }
        }
    }
    return nextrunmode;
}

void Lobby::setNextRunMode(RUNMODE nrm){
	nextrunmode = nrm;
}

void Lobby::setGraphicSet(std::string ogs){
//FIXME        gs->setGraphicSet(ogs);
}

void Lobby::changeMenu(MENUTYPE menutype){
    delete oldmenu;
    oldmenu = menu;
	switch(menutype){
	case CONFIGMENU:
                menu = new ConfigMenu(ui_menu, this, bui);
		break;
	case MAINMENU:
		menu = new MainMenu(ui_menu, this);
		break;
	case QUITMENU:
		menu = new QuitMenu(ui_menu, this);
		break;
	default:
		menu = NULL;
		break;
	}
    menu->refresh();
}

