/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The Lobby provides the menu
 * a player sees when the game 
 * starts. It is the hub to most 
 * other 'RunMode's. */

#ifndef __LOBBY_H__
#define __LOBBY_H__

#include "../shared/RunMode.hpp"
#include "../shared/gui/Menu.hpp"
#include "../shared/gui/GraphicSet.hpp"
#include "../shared/gui/BasicUserInterface.hpp"
#include "../shared/gui/UIMenu.hpp"


/**
 * There are includes defined at the bottom
 * of the file. Did it like that since these
 * Menus need the Lobby to be defined. */

class Lobby : public RunMode{
private:
    UIMenu* ui_menu;

    /** \brief The Menu the Lobby will present
     * to the user. */
    Menu* menu;

    /** \brief A Menu that will shortly not
     * not be used anymore but runs currently.
     *
     * Menus may (and will) trigger the
     * lobby to switch to another menu.
     * Because we do not want the triggering
     * menu to be deleted instantly but we
     * want to create the new one without any
     * delay. We save the pointer to the
     * triggering menu as oldmenu.
     */
    Menu* oldmenu;
	
    RUNMODE nextrunmode;
	
    GraphicSet* gs;
	
    BasicUserInterface* bui;

    INPUTTYPE currinput;
	
public:
    /** will start a Lobby with a UI_Menu
     * and a MainMenu */
    Lobby(GraphicSet* ogs, BasicUserInterface* obui);

    /// deletes Lobby, UI_Menu and menu
    ~Lobby();
	
    RUNMODE run();

    void setNextRunMode(RUNMODE nrm);

    void setGraphicSet(std::string ogs);

    /// deletes menu and creates a new one
    void changeMenu(MENUTYPE menutype);
};

#include "gui/MainMenu.hpp"
#include "gui/ConfigMenu.hpp"
#include "gui/QuitMenu.hpp"

#endif /* __LOBBY_H__ */
