/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef PATHNODE_HPP
#define PATHNODE_HPP

#include "Coordinates.hpp"
#include "../misc/Exceptions.hpp"

class PathNode {
public:
    PathNode();

    PathNode(const PathNode&);

    PathNode( Coordinates pos, PathNode* last, Coordinates to);

#ifdef DEBUG
    /**
     * Destructor is only defined in Debug mode since it
     * is just used for counting initialized instances.
     */
    ~PathNode();
#endif

    /// set field before this one
    /**
     * used when a new, shorter way to this node is found.
     * automatically updates estimated cost
     */
    void setLast(PathNode* last);

    inline PathNode* getLast() {
        return l;
    }

    inline Coordinates getField() const {
        return f;
    }

    inline unsigned int getCost() const {
        return ec;
    }
#ifdef DEBUG
    void check() {
        if (this == l) {
            throw Hexception("PathNode claims to be its own precursor.");
        }
    }
#endif

private:
    /** \brief field
     */
    Coordinates f;

    /// node before this one
    /**
     * pointer to the node that is one
     * step before this one on the shortest
     * possible way currently known
     */
    PathNode* l;

    /** \brief known costs to this node
     */
    unsigned int kc;

    /** \brief estimated total cost
     */
    unsigned int ec;

    /// target field
    Coordinates t;

#ifdef DEBUG
    /** \brief used for counting instances
     */
    static unsigned int instances;
#endif
};

#endif // PATHNODE_HPP
