/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef FSHANDLER_SWITCH
#define FSHANDLER_SWITCH

#ifndef ALLEGRO5
class BstFSHandler;
typedef BstFSHandler FSHandler;
#include "boost/BstFSHandler.hpp"
#else
class Al5FSHandler;
typedef Al5FSHandler FSHandler;
#include "allegro5/Al5FSHandler.hpp"
#endif

#endif // FSHANDLER_SWITCH

#ifndef FSHANDLER_HPP
#define FSHANDLER_HPP

#include <vector>

#include "PathName.hpp"
#include "../misc/Exceptions.hpp"

class VirtualFSHandler {
public:
    /** \short finds files on your filesystem
     *
     * getFullPath(PathName) allows you to work with
     * fake-relative paths
     *
     * \returns absolute path of the (partly) described file
     * empty PathName if file does not exist (throws Hexexption
     */
    PathName getFullPath(PathName filename);

    /** \short prepares directorys for later use
     *
     * \returns nothing, but may throw exceptions
     */
    virtual void prepareDirectory(PathName dir) =0;

    /** sets exedir and adds it to searchdirs */
    virtual void setExeDir(PathName exename) =0;

    /// \returns absolute path to directory of binary
    PathName getExeDir();

    /// \returns absolute path to directory of game content
    PathName getContDir();

    PathName getSettingsDir();

    PathName getHomeDir();

    void addSearchDir(PathName dir);

    bool exists(PathName);

protected:
    virtual bool fileExists(PathName) =0;

    PathName searchpath;
    std::vector<PathName> searchdirs;

    PathName exedir;
    PathName contdir;
    PathName settingdir;
    PathName homedir;
};

#endif // FSHANDLER_HPP
