/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <vector>
#include <iostream>

#ifdef ALLEGRO4
#include <allegro.h>
#else
#include <allegro5/allegro.h>
#endif


#include "MapLoader.hpp"
#include "FSHandler.hpp"
#include "../definitions/Map.hpp"
#include "../definitions/Coordinates.hpp"
#include "../units/UnitContainer.hpp"

int main(int argc, char** argv){
#ifdef ALLEGRO4
    allegro_init();
#else
    al_init();
#endif

    std::string levelname;
    if (argc >= 2) {
        levelname = argv[1];
    } else {
        std::cout << "Usage: ./Maploader-Test.run [name of a map]\n";
        return 0;
    }

    Map* testmap;
    UnitContainer* unit;
    FSHandler* fsh = new FSHandler();

#ifdef ALLEGRO4
    char exename[128];
    get_executable_name(exename,sizeof(exename));
    fsh->setExeDir(PathName(exename));
#else
    ALLEGRO_PATH* exedir = al_get_standard_path(ALLEGRO_EXENAME_PATH);
    fsh->setExeDir( PathName(al_path_cstr(exedir, ALLEGRO_NATIVE_PATH_SEP)));
    al_destroy_path(exedir);
#endif

    MapLoader* ml;
    ml = new MapLoader(fsh);
    ml->loadMap(levelname);
    testmap = ml->getMap();
    unit = ml->getUnits();

    std::cout << testmap->getAscii() << std::endl;
    std::cout << unit->getAscii() ;

    delete testmap;
    delete fsh;
    delete unit;
    delete ml;

#ifdef ALLEGRO4
    allegro_exit();
#endif

    return 0;
}
