/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "Al5FSHandler.hpp"

Al5FSHandler::Al5FSHandler() {
    contdir = "/usr/share/hexwars/";
    if (fileExists(contdir)) {
        addSearchDir(contdir);
    }

    addSearchDir("./");

    ALLEGRO_PATH* alexedir = al_get_standard_path(ALLEGRO_EXENAME_PATH);
    al_set_path_filename(alexedir, NULL);

    exedir = PathName( al_path_cstr( alexedir, ALLEGRO_NATIVE_PATH_SEP ));
    addSearchDir( exedir );
    addSearchDir( exedir /= "../");

    settingdir = pathName( ALLEGRO_USER_SETTINGS_PATH );
    if (exists(settingdir)) {
        addSearchDir( settingdir );
    }

    homedir = pathName( ALLEGRO_USER_HOME_PATH     ) /= ".hexwars/";
    addSearchDir( homedir );

    al_destroy_path(alexedir);
}

Al5FSHandler::~Al5FSHandler() {
    searchdirs.clear();
}

void Al5FSHandler::prepareDirectory(PathName dir) {
    al_make_directory(dir.c_str());
}

void Al5FSHandler::setExeDir(PathName exename) {
    return;
}

PathName Al5FSHandler::pathName(int al_id){
    ALLEGRO_PATH* alpath = al_get_standard_path(al_id);
    PathName path = al_path_cstr(alpath,ALLEGRO_NATIVE_PATH_SEP);
    al_destroy_path(alpath);
    return path;
}

bool Al5FSHandler::fileExists(PathName path) {
    bool answer;
    ALLEGRO_FS_ENTRY* fsentry = al_create_fs_entry(path.c_str());
    answer = al_fs_entry_exists(fsentry);
    al_destroy_fs_entry(fsentry);
    return answer;
}
