/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Al5MapLoader.hpp"

Al5MapLoader::Al5MapLoader(FSHandler* ofsh) {
    fsh = ofsh;
}

Al5MapLoader::~Al5MapLoader() {
    mapload.clear();
}

void Al5MapLoader::loadMapFromDisk(PathName fullpath) {
    mapload.open(fullpath.c_str());
    char Version[10];
    for (int i=0;i<9;i++){
        mapload >> Version[i];
    }
    Version[9] = '\0';
        /* check version string of the map; later versions
         * of hexwars may support greater levels, more units. */
    if (std::string(Version) == "HWmap_V01"){
        load_HWmap_V01();
    } else if (std::string(Version) == "HWmap_V02"){
        load_HWmap_V02();
    } else {
        throw Hexception("Unknown map format or map not found.\n");
    }
    return;
}

void Al5MapLoader::saveMapToDisk(PathName fullpath, unsigned int version) {
    std::ofstream ofs;
    ofs.open(fullpath.c_str(), std::fstream::trunc);

    switch (version) {
    case 1:
        ofs << encode_HWmap_V01();
        break;
    case 2:
        ofs << encode_HWmap_V02();
        break;
    default:
        break;
    }
    ofs.close();
}

void Al5MapLoader::load_HWmap_V01() {
    //load the size of the map
    unsigned int X, Y;
    mapload >> X;
    mapload >> Y;
    map = new Map(X,Y,1);
    player = new UnitContainer(map);

    //load all data into a 2D array
    unsigned int tmpmap[32][32];
    for (unsigned int y=Y; y>0; y--) {
        for (unsigned int x=0; x<X; x++) {
            mapload >> (tmpmap[x][Y-y]);
        }
    }

    if(!mapload.good()){
        throw Hexception("Error loading map.\n");
        mapload.close();
        return;
    }

    mapload.close();

    //parse data from 2D array
    decode_HWmap_V01(tmpmap);
}

void Al5MapLoader::load_HWmap_V02() {
    //load the size of the map
    unsigned int X, Y;
    mapload >> X;
    mapload >> Y;
    map = new Map(X,Y,1);
    player = new UnitContainer(map);

    //load all data into a string
    std::stringstream mapstring;
    char tmp[256];

    while (mapload.good()) {
        mapload.getline(tmp,256);
        mapstring << tmp << std::endl;
    }

    mapload.close();

    //parse data from string
    decode_HWmap_V02(mapstring.str());
}
