/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Al5PathName.hpp"

Al5PathName::Al5PathName() {
    pathname = NULL;
}

Al5PathName::Al5PathName(const char* path) {
    pathname = NULL;
    setPathName(path);
}

Al5PathName::Al5PathName(std::string path) {
    pathname = NULL;
    setPathName(path);
}

Al5PathName::Al5PathName(const Al5PathName& orig) {
    pathname = orig.pathname;
    pathname = al_create_path(c_str());
}

Al5PathName::~Al5PathName() {
    al_destroy_path(pathname);
}

std::string Al5PathName::string() {
    const char* strg = c_str();
    if (strg != NULL) {
        return std::string(strg);
    } else {
        return std::string("/");
    }
}

const char* Al5PathName::c_str() {
    al_make_path_canonical(pathname);
    return al_path_cstr(pathname, ALLEGRO_NATIVE_PATH_SEP);
}

ALLEGRO_PATH* Al5PathName::al5Path() {
    return pathname;
}

bool Al5PathName::exists() {
    return al_fs_entry_exists( al_create_fs_entry(c_str()) );
}

Al5PathName Al5PathName::operator=(const char* path) {
    setPathName(path);
    return *this;
}

Al5PathName Al5PathName::operator=(std::string path) {
    setPathName(path);
    return *this;
}

Al5PathName Al5PathName::operator=(Al5PathName path) {
    setPathName(path);
    return *this;
}

Al5PathName  Al5PathName::operator/=(const char* subdir) {
    append(subdir);
    return *this;
}

Al5PathName  Al5PathName::operator/=(std::string subdir) {
    append(subdir);
    return *this;
}

Al5PathName Al5PathName::operator/=(Al5PathName subdir) {
    append(subdir.c_str());
    return *this;
}

Al5PathName Al5PathName::operator/(const char* subdir) {
    Al5PathName path(c_str());
    path.append(subdir);
    return path;
}

void Al5PathName::append(std::string subdir) {
    append(subdir.c_str());
}

void Al5PathName::append(const char* subdir) {
    ALLEGRO_PATH* basepath = al_create_path_for_directory(c_str());
    al_destroy_path(pathname);
    pathname = al_create_path(subdir);
    al_rebase_path(basepath, pathname);
    al_destroy_path(basepath);
}

void Al5PathName::setPathName(std::string path) {
    setPathName(path.c_str());
}

void Al5PathName::setPathName(const char* path) {
    al_destroy_path(pathname);
    pathname = al_create_path(path);
}

void Al5PathName::setPathName(Al5PathName path) {
    setPathName(path.c_str());
}
