/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Menu.hpp"

Menu::Menu(){
    selecteditem = 0;
}

Menu::~Menu(){
    clear();
}

unsigned int Menu::numOfItems(){
    return item.size();
}

std::string Menu::getItemText(unsigned int n){
    return (*item[n]).getText();
}


MENUITEMMODE Menu::getItemMode(unsigned int n){
    return (*item[n]).getMode();
}

int Menu::selectNextItem(){

    // go to next item
    if (doselect < item.size()-1){
        doselect++;
    }
    else{
        doselect = 0;
    }
    
    // select if possible
    selectItem(doselect);

    /* The following is true if selection was
     * successful or if there is only one item.
     * If there is only one selectable item it
     * will prevent infinite loops.
     */
    if (selecteditem != doselect){
        selectNextItem();
    }

    return selecteditem;
}

void Menu::clear() {
    while(!item.empty()) {
        delete item.back();
        item.pop_back();
    }
}

int Menu::selectPrevItem(){

    // go to next item
    if (doselect > 0){
        doselect--;
    }
    else{
        doselect = item.size()-1;
    }

    // select if possible
    selectItem(doselect);

    /* The following is true if selection was
     * successful or if there is only one item.
     * If there is only one selectable item it
     * will prevent infinite loops.
     */
    if (selecteditem != doselect){
        selectPrevItem();
    }


    return selecteditem;
}

bool Menu::selectItem(unsigned int ds){
    // check, if item to select exists
    if(ds < item.size()){
        switch((*item[ds]).getMode()){
        case HEADLINE:
            return false;
        case ENABLED:
            doselect = ds;
            // unselect currenty selected item
            (*item[selecteditem]).setMode(ENABLED);
            // select item to select
            (*item[doselect]).setMode(SELECTED);
            // save newly selected item in the Menu object
            selecteditem = doselect;
            return true;
        case SELECTED:
            doselect = ds;
            selecteditem = doselect;
            return true;
        default:
            return false;
        }
    }
    return false;
}

void Menu::runSelectedItem(){
    runItem(selecteditem,0);
}

int Menu::getSelectedItem(){
    return selecteditem;
}

void Menu::refresh(){
    margin = 32;
    display->lockScreen(true);
    display->clear();
    display->drawBox();
    for(unsigned int i=0; i<numOfItems(); i++){
        display->drawText(getItemText(i), getItemMode(i), i*margin+32);
    }
    display->lockScreen(false);
}

void Menu::specificInput(INPUTTYPE parinput){
    switch(parinput){
    case UP:
        currinput = SCROLL;
        selectPrevItem();
        refresh();
        print();
        return;
    case DOWN:
        currinput = SCROLL;
        selectNextItem();
        refresh();
        print();
        return;
    case LEFT:
        runItem(selecteditem, -1);
        if (currinput == NOINPUT) {
            currinput = SCROLL;
        }
        print();
        return;
    case RIGHT:
        runItem(selecteditem, +1);
        if (currinput == NOINPUT) {
            currinput = SCROLL;
        }
        print();
        return;
    case SELECT:
        currinput = MENUSELECT;
        runSelectedItem();
        return;
    case LMB:
        pointerpos = display->getPointerPos();
        /* this check prevents the menu from runing an
         * item that is not being newly selected
         */
        if(pointerpos == Coordinates(-1,-1)) {
            currinput = NOINPUT;
            return;
        }
        if (selectItem((pointerpos.y-16)/margin)) {
            refresh();
            currinput = MENUSELECT;
            runSelectedItem();
        } else {
            currinput = MOVEMENU;
        }
        return;
    case RMB:
        pointerpos = display->getPointerPos();
        if(pointerpos == Coordinates(-1,-1)) {
            currinput = NOINPUT;
            return;
        } else {
            currinput = HOVER;
            return;
        }
    case QUIT:
        currinput = QUIT;
        return;
    default:
        break;
    }
    currinput = NOINPUT;
    return;
}

