/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <vector>
#include <string>

#ifndef __MENU_H__INCLUDE1__
#define __MENU_H__INCLUDE1__

#include "MenuItem.hpp"

#endif /* __MENU_H__INCLUDE1__ */

#ifndef __MENU_H__
#define __MENU_H__


typedef unsigned int MENUTYPE;
enum Menutypes{
    NOMENU =0, FLOATINGMENU =1, MAINMENU, CONFIGMENU, QUITMENU
};

#include "UIMenu.hpp"
#include "IE.hpp"
#include "../definitions/Coordinates.hpp"

class Menu : public IE {
public:
    /**
     * Constructor without input is defined for child
     * classes. It will only set selecteditem to 0.
     */
    Menu();
    
    /**
     * deletes all items
     */
    ~Menu();
    
    /**
     * refreshes all the contents seen on the screen
     * except the pointer. This will NOT draw anything
     * on the screen.
     */
    void refresh();
	
protected:
    std::vector<MenuItem*> item;
    
    /** \brief selects the item that has the given number
     * 
     * \returns if selection was succesful
     */
    bool selectItem(unsigned int);

    UIMenu* display;

    /** \brief deletes MenuItems
     *
     * Deletes MenuItems one by one. This is necessary
     * because item just stores pointers and so item.clear()
     * will not free the memory.
     */
    void clear();

private:
    void specificInput(INPUTTYPE parinput);

    /// saves which item is selected
    unsigned int selecteditem;

    /// saves which item is tried to select
    unsigned int doselect;

    unsigned int numOfItems();

    /**
     * moves selection to the next/ previous
     * item and returns which item was selected
     * or '-1' if the operation was not successful
     */
    int selectNextItem();
    int selectPrevItem();

    /// runs the selected item
    inline void runSelectedItem();
    
    /// runs the selected item
    virtual void runItem(unsigned int, int) = 0;

    /// returns the text of the specified item
    std::string getItemText(unsigned int);

    /**
     * \returns the mode of the specified item
     */

    MENUITEMMODE getItemMode(unsigned int);

    /**
     * \returns which item is selected
     */
    inline int getSelectedItem();

    /// This saves the size the menu has on screen.
    Coordinates screensize;

    /// the position of the pointer
    Coordinates oldpointerpos;
    Coordinates pointerpos;

    /// space between entries
    unsigned int margin;
};

#endif /* __MENU_H__ */
