/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __MENUITEM__
#define __MENUITEM__

#include <string>

// begin of class UI_MenuItem will follow after some definitions

enum MenuItemModes {
	DISABLED = 0,
	ENABLED = 1,
	SELECTED = 2,
	HEADLINE = 3,
	
	NUMOFMODES = 4
}; // needed to track the items state

typedef unsigned int MENUITEMMODE;
// this typedef is needed by the following class only


/**
 * MenuItems consist of a text
 * and a status (defined via
 * MenuItemMode, see above)
 */
class MenuItem{
public:
    /** creates a MenuItem with the given
     * text; as defined obove, modes can be:
     * DISABLED, ENABLED, SELECTED or HEADLINE
     */
    MenuItem(std::string, MENUITEMMODE);
    
    MenuItem();
    
    std::string getText();
    // returns the text of the item
    
    MENUITEMMODE getMode();
    // returns the mode of the item
    
    /**
     * lets you set the mode of this
     * MenuItem. Will not do anything if
     * MenuItem is DISABLED
     */
    void setMode(MENUITEMMODE);
private:
    // the text of the item
    std::string text;
    
    // saves the mode of the item
    MENUITEMMODE mode;
};
// end of UI_MenuItem

#endif /* __MENUITEM__ */
