/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "UIEngine.hpp"
#include "BasicUserInterface.hpp"
#include "GraphicSet.hpp"

#include "../filesystem/FSHandler.hpp"
#include "../definitions/Coordinates.hpp"

int main(){
#ifndef ALLEGRO4
    if (!al_init()) {
        std::cerr << "Failed to initialize allegro.\n";
        exit(-1);
    }
#endif

    FSHandler* fsh = new FSHandler;

    BasicUserInterface* bui = new BasicUserInterface(fsh);
    GraphicSet* gs = new GraphicSet(std::string("modernart"), fsh);
    bui->setGraphicSet(gs);
    UIEngine* ui_engine = new UIEngine(bui->getSize(), Coordinates(0,0), gs, bui);
    Coordinates posi = Coordinates(32,32);
    INPUTTYPE lastinput;

    bool endloop = false;
    while ( !endloop ) {
        lastinput = bui->getInput(NOINPUT);
        switch (lastinput) {
        case QUIT:
            endloop = true;
            break;
        case LEFT:
            posi.x -= 64;
            break;
        case RIGHT:
            posi.x += 64;
            break;
        case UP:
            posi.y -= 64;
            break;
        case DOWN:
            posi.y += 64;
            break;
        case NOINPUT:
            ui_engine->lockScreen(true);
            ui_engine->clearBlack();
            ui_engine->drawTerrain(WATER, Coordinates(100,100));
            ui_engine->drawUnit(TERRAFORMER, PLAYER1 ,posi);
            ui_engine->lockScreen(false);

            ui_engine->print();
            break;
        }

        if( posi.x > bui->getSize().x - 32) {
            posi.x = bui->getSize().x - 32;
        }
        if( posi.x < 32 ){
            posi.x = 32;
        }
        if( posi.y < 32){
            posi.y = 32;
        }
        if( posi.y > bui->getSize().y - 64){
            posi.y = bui->getSize().y - 64;
        }
    }

    delete bui;
    delete gs;
    delete ui_engine;
    delete fsh;

#ifndef ALLEGRO4
    al_uninstall_system();
#endif
}
