/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al4UIEngine.hpp"

Al4UIEngine::Al4UIEngine(Coordinates size, Coordinates pos, GraphicSet* gs, UI* par){
    init(size, pos, gs, par);
    tilesize.x = (graphics->water1)->w;
    tilesize.y = (graphics->water1)->h;
    unitsize.x = (graphics->warrior[1])->w;
    unitsize.y = (graphics->warrior[1])->h;
}

Al4UIEngine::~Al4UIEngine(){
    ;
}

void Al4UIEngine::drawLine(std::vector<Coordinates> coos, int col){
    if (coos.size() >= 2){
        for (unsigned int i=0; i<coos.size()-1 ; i++){
            drawLine(coos[i], coos[i+1], col);
        }
    }
}

void Al4UIEngine::drawTerrain(TERRAINTYPE type, Coordinates pos){
    switch(type){
    case BLACK:
        masked_blit( graphics->fogtile,buffer,0,0,pos.x,pos.y,tilesize.x,tilesize.y);
        break;
    case WATER:
        masked_blit( graphics->water1,buffer,0,0,pos.x,pos.y,tilesize.x,tilesize.y);
        break;
    case GRASS:
        masked_blit( graphics->grass1,buffer,0,0,pos.x,pos.y,tilesize.x,tilesize.y);
        break;
    default:
        break;
    }
}

void Al4UIEngine::drawUnit(UNITTYPE type, PLAYER owner, Coordinates pos){
    switch(type){
    case SPIRIT:
        masked_blit( graphics->spirit[owner],buffer,0,0,pos.x-unitsize.x/2,pos.y,unitsize.x,unitsize.y);
        break;
    case WARRIOR:
        masked_blit( graphics->warrior[owner],buffer,0,0,pos.x-unitsize.x/2,pos.y,unitsize.x,unitsize.y);
        break;
    case SCOUT:
        masked_blit( graphics->scout[owner],buffer,0,0,pos.x-unitsize.x/2,pos.y,unitsize.x,unitsize.y);
        break;
    case TERRAFORMER:
        masked_blit( graphics->terraf[owner],buffer,0,0,pos.x-unitsize.x/2,pos.y,unitsize.x,unitsize.y);
        break;
    case MAGICIAN:
        masked_blit( graphics->magician[owner],buffer,0,0,pos.x-unitsize.x/2,pos.y,unitsize.x,unitsize.y);
        break;
    case FOG:
        masked_blit( graphics->fog,buffer,0,0,pos.x,pos.y,tilesize.x,tilesize.y);
        break;
    default:
        break;
    }
}

void Al4UIEngine::drawFocus(FOCUSTYPE type, Coordinates pos) {
    masked_blit( graphics->focus[type],buffer,0,0,pos.x,pos.y,graphics->focus[type]->w,graphics->focus[type]->h);
}

void Al4UIEngine::lockScreen(bool doit){
    if(doit)
        acquire_bitmap(buffer);
    else
        release_bitmap(buffer);
}

Coordinates Al4UIEngine::getTileSize(){
    return tilesize;
}
