/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The Al4UI_Engine is capable of input and
 * output of the Engine. There might be
 * different versions for different libs
 * (e.g. allegro, glut, ...) in the
 * future. */

#ifndef __Al4UI_Engine__H__
#define __Al4UI_Engine__H__

class Al4UIEngine;
typedef Al4UIEngine UIEngine;

#include <allegro.h>
#include <vector>

#include "../UIEngine.hpp"
#include "../../definitions/Coordinates.hpp"
#include "../../definitions/Map.hpp"
#include "../../units/Unit.hpp"
#include "../virtual/VirtualUIEngine.hpp"
#include "../GraphicSet.hpp"
#include "../UI.hpp"
#include "../MenuItem.hpp"

class Al4UIEngine : public UI, public VirtualUIEngine{
public:
    /**
     * initializes the user interface of the engine,
     * will create a doublebuffer and load graphics
     */
    Al4UIEngine(Coordinates s, Coordinates p, GraphicSet* gs, UI* par);

    ~Al4UIEngine();

    /** Connects the given Coordinates by a line. */
    void drawLine(std::vector<Coordinates> coos, int col);
    void drawLine(Coordinates from, Coordinates to, int col){
        fastline( buffer, from.x, from.y, to.x, to.y,
            makecol(col/0x10000,col/0x100%0x100,col%0x100));
    }

    /** Draws the terrain on the given position on the
     * screen or in the window. */
    void drawTerrain(TERRAINTYPE type, Coordinates pos);

    /** Draws the unit on the given position on the
     * screen or in the window. */
    void drawUnit(UNITTYPE type, PLAYER owner, Coordinates pos);

    /** Draws selections. */
    void drawFocus( FOCUSTYPE type, Coordinates pos );

    /**
     *  Locks or unlocks the screen. With some graphic libs
     *  a higher drawing performance may be accomplished with
     *  a locked screen.
     */
    void lockScreen(bool doit);

    /**
     *  \returns size of the current GraphicSets' tiles
     */
    Coordinates getTileSize();
};


#endif /* __Al4UI_Engine__H__ */
