/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __Al4UI_Menu_H__INCLUDE__
#define __Al4UI_Menu_H__INCLUDE__

#include <vector>
#include <string>
#include <allegro.h>

#include "../MenuItem.hpp"
#include "../UI.hpp"
#include "../GraphicSet.hpp"
#include "../../definitions/Coordinates.hpp"

#endif /* __Al4UI_Menu_H__INCLUDE__ */
#ifndef __Al4UI_Menu_H__
#define __Al4UI_Menu_H__

/**
 * This class does not provide a functional
 * menu but only the userinterface for
 * one. It needs an object of class 'Menu'
 * to work. */

class Al4UIMenu;
typedef Al4UIMenu UIMenu;

class Al4UIMenu : public UI{
public:
    /**
     * this will create a Al4UI_Menu of size with a upper
     * left edge at pos
     *
     * \param size size of the menu on screen
     * \param pos position of the menu on screen
     * \param gs Set of bitmaps
     * \param par parent userinterface (the Al4UI_Menu is nested in that UI)
     */
    Al4UIMenu(Coordinates size, Coordinates pos, GraphicSet* gs, UI* par);

    ~Al4UIMenu();

    void drawBox();

    /**
     * draws the given text at the given position
     */
    void drawText(std::string text, MENUITEMMODE, unsigned int pos);

    /**
     * draws the given text at the given position
     */
    void drawTextLeft(std::string text, MENUITEMMODE, Coordinates pos);

    /**
     * draws the given text at the given position
     */
    void drawTextCenter(std::string text, MENUITEMMODE, Coordinates pos);

    /**
     * draws the given text at the given position
     */
    void drawTextRight(std::string text, MENUITEMMODE, Coordinates pos);

private:
    /** calculate colors for diffent
     *  modes of menu items
     */
    void calcColors(MENUITEMMODE);

    /** color of printed text
     */
    int fg;

    /** background of printed text
     */
    int bg;

};

#endif /* __Al4UI_Menu_H__ */

