/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al5UIEngine.hpp"

Al5UIEngine::Al5UIEngine(Coordinates size, Coordinates pos, GraphicSet* gs, UI* par){
    ;

    init(size, pos, gs, par);
    tilesize.x = al_get_bitmap_width(graphics->water1);
    tilesize.y = al_get_bitmap_height(graphics->water1);
    unitsize.x = al_get_bitmap_width(graphics->warrior[1]);
    unitsize.y = al_get_bitmap_height(graphics->warrior[1]);
}

Al5UIEngine::~Al5UIEngine(){
    ;
}

void Al5UIEngine::drawLine(Coordinates from, Coordinates to, int col){
    al_set_target_bitmap(buffer);
    al_draw_line( from.x, from.y, to.x, to.y,
                  al_map_rgb(col/0x10000,col/0x100%0x100,col%0x100),1);
}

void Al5UIEngine::drawLine(std::vector<Coordinates> coos, int col){
    if (coos.size() >= 2){
        for (unsigned int i=0; i<coos.size()-1 ; i++){
            drawLine(coos[i], coos[i+1], col);
        }
    }
}

void Al5UIEngine::drawTerrain(TERRAINTYPE type, Coordinates pos){
    al_set_target_bitmap(buffer);
    switch(type){
    case BLACK:
        al_draw_bitmap( graphics->fogtile,pos.x,pos.y,0);
        break;
    case WATER:
        al_draw_bitmap( graphics->water1,pos.x,pos.y,0);
        break;
    case GRASS:
        al_draw_bitmap( graphics->grass1,pos.x,pos.y,0);
        break;
    default:
        break;
    }
}

void Al5UIEngine::drawUnit(UNITTYPE type, PLAYER owner, Coordinates pos){
    switch(type){
    case SPIRIT:
        al_draw_bitmap( graphics->spirit[owner],pos.x-unitsize.x/2,pos.y,0);
        break;
    case WARRIOR:
        al_draw_bitmap( graphics->warrior[owner],pos.x-unitsize.x/2,pos.y,0);
        break;
    case SCOUT:
        al_draw_bitmap( graphics->scout[owner],pos.x-unitsize.x/2,pos.y,0);
        break;
    case TERRAFORMER:
        al_draw_bitmap( graphics->terraf[owner],pos.x-unitsize.x/2,pos.y,0);
        break;
    case MAGICIAN:
        al_draw_bitmap( graphics->magician[owner],pos.x-unitsize.x/2,pos.y,0);
        break;
    case FOG:
        al_draw_bitmap( graphics->fog,pos.x,pos.y,0);
        break;
    default:
        break;
    }
}

void Al5UIEngine::drawFocus( FOCUSTYPE type, Coordinates pos ){
    al_draw_bitmap( graphics->focus[type],pos.x,pos.y,0);
}

Coordinates Al5UIEngine::getTileSize(){
    return tilesize;
}
