/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al5UIMenu.hpp"

Al5UIMenu::Al5UIMenu(Coordinates size, Coordinates pos, GraphicSet* gs, UI* par){
    init(size, pos, gs, par);
}

Al5UIMenu::~Al5UIMenu(){
    ;
}

void Al5UIMenu::drawBox(){
    al_set_target_bitmap(buffer);
    clearBlack();
    al_draw_rounded_rectangle(4,4,size.x-4,size.y-4,8,8,al_map_rgb(255,255,255),1);
}

void Al5UIMenu::drawTextLeft(std::string text, MENUITEMMODE mode, Coordinates pos){
    al_set_target_bitmap(buffer);
    calcColors(mode,pos);
    al_draw_text(UI::font, color, pos.x, pos.y, ALLEGRO_ALIGN_LEFT, text.c_str());
}

void Al5UIMenu::drawTextCenter(std::string text, MENUITEMMODE mode, Coordinates pos){
    al_set_target_bitmap(buffer);
    calcColors(mode,pos);
    al_draw_text(UI::font, color, pos.x, pos.y, ALLEGRO_ALIGN_CENTRE, text.c_str());
}

void Al5UIMenu::drawTextRight(std::string text, MENUITEMMODE mode, Coordinates pos){
    al_set_target_bitmap(buffer);
    calcColors(mode,pos);
    al_draw_text(UI::font, color, pos.x, pos.y, ALLEGRO_ALIGN_RIGHT, text.c_str());
}

void Al5UIMenu::calcColors(MENUITEMMODE mode, Coordinates pos){
    switch(mode){
    case HEADLINE:
        color = al_map_rgb(255,0,0);
        break;
    case SELECTED:
        color = al_map_rgb(255,255,255);
        al_draw_line(pos.x-16,pos.y,pos.x+16,pos.y,al_map_rgb(255,0,0),2);
        al_draw_line(pos.x-16,pos.y+24,pos.x+16,pos.y+24,al_map_rgb(255,0,0),2);
        break;
    case DISABLED:
        color = al_map_rgb(127,127,127);
        break;
    default:
        color = al_map_rgb(191,191,191);
        break;
    }
}
