/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __VirtualBasicUserInterface_HPP__
#define __VirtualBasicUserInterface_HPP__

#include "VirtualUI.hpp"
#include "../GraphicSet.hpp"
#include "../../definitions/Coordinates.hpp"
#include "../../filesystem/PathName.hpp"
#include "../../filesystem/FSHandler.hpp"

/** \brief responsable for display and input operations
 *
 *  Al5BasicUserInterface is responsable for recognizing basic
 *  user inputs (defined in UI) and for managing Hexwars
 *  display or window. It provides the ground UI::buffer
 *  which is used as a double buffer.
 *
 */


class VirtualBasicUserInterface {
public:
    virtual void setFullscreen(bool) =0;
    virtual bool getFullscreen() =0;

    virtual void setResolution(int, int, int) =0;
    virtual void setResolution(Coordinates, int) =0;


    /** \brief does nothing until input (or timer)
     *
     *  Since we have a timer running, there will be at least
     *  $(FPS) events every second that cause a redraw. If the
     *  player is highly active, there might be more to do ^^.
     *  Returns user input done by keys.
     *
     *  This will return a keycode as defined in UI if the player
     *  presses one of the keys bind to this action. If no key
     *  is pressed for a time defined by FPS it will return TIME
     *  instead.
     *
     * \returns code for user input
     */
    virtual INPUTTYPE getInput(INPUTTYPE currinput) =0;

    /**
     * Sets the screen resolution, fullscreen, etc.
     * You need to call this after switching resolution
     * et al.
     */
    virtual void setGraphicMode() =0;

    virtual void print() =0;

    virtual void saveUIConfig() =0;

    virtual void message(const char* msg) =0;
};

#endif // __VirtualBasicUserInterface_HPP__
