/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef VIRTUALUIENGINE_HPP
#define VIRTUALUIENGINE_HPP

#include "../../definitions/Coordinates.hpp"
#include "../../units/Unit.hpp"
#include "VirtualUI.hpp"


typedef unsigned int FOCUSTYPE;
enum Focustypes {
    FOCUS_SUMONPOS=0, FOCUS_SELECTION=1
};

class VirtualUIEngine {
public:
    /** Connects the given Coordinates by a line. */
    virtual void drawLine(Coordinates from, Coordinates to, int col) =0;
    virtual void drawLine(std::vector<Coordinates> coos, int col) =0;

    /** Draws the terrain on the given position on the
     * screen or in the window. */
    virtual void drawTerrain(TERRAINTYPE type, Coordinates pos) =0;

    /** Draws the unit on the given position on the
     * screen or in the window. */
    virtual void drawUnit(UNITTYPE type, PLAYER owner, Coordinates pos) =0;

    /** Draws selections. */
    virtual void drawFocus(FOCUSTYPE type, Coordinates pos) =0;

    /**
     *  Used for compatibilty with other libs.
     */
    virtual void lockScreen(bool doit) =0;

    /**
     *  \returns size of the current GraphicSets' tiles
     */
    virtual Coordinates getTileSize() =0;

protected:
    Coordinates tilesize;
    Coordinates unitsize;
};

#endif // VIRTUALUIENGINE_HPP
