/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* This is meant to be used to test the 
 * implementation of units. */


#include <iostream>
#include <iomanip>

#include "../definitions/Coordinates.hpp"
#include "UnitContainer.hpp"
#include "Magician.hpp"
#include "Warrior.hpp"
#include "Scout.hpp"
#include "Spirit.hpp"
#include "TerraFormer.hpp"

void unitInfo(UnitContainer* showme){
    for(unsigned int i=1; i<=showme->getLatestUuid(); i++){
        Unit* unit = showme->getUnit(i);
        if (unit != NULL){
            std::cout << std::setw(2) << i << ": "
                      << unit->getOwner() << ", "
                      << "(" <<  unit->getPos().x
                      << "/" << unit->getPos().y << "), ";
            switch(unit->getType()){
            case WARRIOR:
                std::cout << "Wario";
                break;
            case SCOUT:
                std::cout << "Scout";
                break;
            case TERRAFORMER:
                std::cout << "Teraf";
                break;
            case MAGICIAN:
                std::cout << "Magic";
                break;
            case SPIRIT:
                std::cout << "Spirt";
                break;
            default:
                std::cout << "none ";
                break;
            }
            std::cout << ", " << std::setw(3) << unit->getHp() << std::endl;
        }
    }
}

int main(int argc, char** argv){
    UnitContainer* units;
    UnitContainer* ntcht;

    units = new UnitContainer(NULL);
    units->saveUnit(new Scout       (Coordinates(1,2), PLAYER1));
    units->saveUnit(new Warrior     (Coordinates(1,2), PLAYER1));
    units->saveUnit(new Warrior     (Coordinates(1,3), PLAYER1));
    units->saveUnit(new Warrior     (Coordinates(1,3), PLAYER2));
    units->saveUnit(new TerraFormer (Coordinates(1,4), PLAYER1));
    units->saveUnit(new Warrior     (Coordinates(1,4), PLAYER2));
    units->saveUnit(new TerraFormer (Coordinates(1,5), PLAYER1));
    units->saveUnit(new Scout       (Coordinates(1,5), PLAYER2));
    units->saveUnit(new TerraFormer (Coordinates(1,6), PLAYER1));
    units->saveUnit(new Spirit      (Coordinates(1,6), PLAYER2));
    units->saveUnit(new TerraFormer (Coordinates(1,7), PLAYER2));
    units->saveUnit(new Spirit      (Coordinates(1,7), PLAYER2));
    units->saveUnit(new Warrior     (Coordinates(1,8), PLAYER1));
    units->saveUnit(new Spirit      (Coordinates(1,8), PLAYER2));

    units->getUnit(Coordinates(1,2))->changeHp(5);

    ntcht = new UnitContainer(*units);

    std::cout	<< "This is a test utility for units."
                   "It will show all Units in the format "
                   "'ID: Owner, Position, Type, HitPoints'\n";

    std::cout << std::endl << "-------------------------------" << std::endl;
    std::cout << "Units that will fight:" << std::endl;
    unitInfo(units);

    std::cout << std::endl << "-------------------------------" << std::endl;
    std::cout << "Units after the fight:" << std::endl;
    units->doMovement();
    unitInfo(units);

    std::cout << std::endl << "-------------------------------" << std::endl;
    std::cout << "Units that are still alive:" << std::endl;
    units->tidy();
    unitInfo(units);

    std::cout << std::endl << "-------------------------------" << std::endl;
    std::cout << "Copy of original Units:" << std::endl;
    unitInfo(ntcht);

    delete units;
    delete ntcht;
}
